<p align="center">
    <a href="https://sylius.com" target="_blank">
        <img src="https://demo.sylius.com/assets/shop/img/logo.png" />
    </a>
</p>

<h1 align="center">Plugin Skeleton</h1>

<p align="center">Skeleton for starting Sylius plugins.</p>

## Documentation

For a comprehensive guide on Sylius Plugins development please go to Sylius documentation,
there you will find the <a href="https://docs.sylius.com/en/latest/plugin-development-guide/index.html">Plugin Development Guide</a>, that is full of examples.

## Quickstart Installation

```bash
$ make start
$ make db-create
$ make db-update
$ make fixtures
$ make build
```


## Installation

1. [Install Sylius](https://docs.sylius.com/en/latest/book/installation/installation.html)
2. Install **Sylius Dedi Contact**: `composer require dedi/sylius-contact-plugin`
3. Register the bundle:

    ```php
    <?php

    // config/bundles.php

    return [
        // ...
        Dedi\SyliusContactPlugin\DediSyliusContactPlugin::class => ['all' => true],
        EWZ\Bundle\RecaptchaBundle\EWZRecaptchaBundle::class => ['all' => true]    
   ];

4. Import the configuration:

    ```yaml
    # config/packages/_sylius.yaml
    imports:
        - { resource: "@DediSyliusContactPlugin/Resources/config/config.yaml" }
     ```

5. Configure `EWZRecaptchaBundle`

    ```yaml
    # config/packages/ewz_recaptcha.yaml

    ewz_recaptcha:
        public_key: '%env(GOOGLE_RECAPTCHA_SITE_KEY)%'
        private_key: '%env(GOOGLE_RECAPTCHA_SECRET)%'
    ```

    ```
    # .env

    # Recaptcha public key setter for contact form
    GOOGLE_RECAPTCHA_SITE_KEY=
    # Recaptcha secret key setter for contact form
    GOOGLE_RECAPTCHA_SECRET=
    ```

    Use [ReCaptcha Admin](https://www.google.com/recaptcha/admin) to generate your keys

6. Import the routes:

    :warning: routes should be imported after `sylius_shop`

    ```yaml
    # config/routes/routes.yaml
    dedi_sylius_contact_form_plugin:
        resource: "@DediSyliusContactPlugin/Resources/config/routing.yaml"
    ```

7. Override the templates:

       mkdir -p templates/bundles/DediSyliusContactPlugin/
       cp -R vendor/dedi/sylius-contact-plugin/src/Resources/views/* templates/bundles/DediSyliusContactPlugin/

    The template you should override is `Shop/ContactFormSubject/form.html.twig`

8. Create and execute database migrations:

       bin/console doctrine:migrations:diff
       bin/console doctrine:migrations:migrate

9. Configure the plugin

    ```yaml
    dedi_sylius_contact_plugin:
        invisible_captcha: false # false by default
        phone_number: '^(?:(?:\+|00)33|0\s*[1-9(?:[\s.-]*\d{2}){4$' # french phone number pattern by default
    ```

   :warning: reCAPTCHA key for `normal` captcha can't be used for `invisible` captcha.

## Usage

### Running plugin tests

  - PHPUnit

    ```bash
    $ vendor/bin/phpunit
    ```

  - PHPSpec

    ```bash
    $ vendor/bin/phpspec run
    ```

  - Behat (non-JS scenarios)

    ```bash
    $ vendor/bin/behat --tags="~@javascript"
    ```

  - Behat (JS scenarios)
 
    1. Download [Chromedriver](https://sites.google.com/a/chromium.org/chromedriver/)
    
    2. Download [Selenium Standalone Server](https://www.seleniumhq.org/download/).
    
    2. Run Selenium server with previously downloaded Chromedriver:
    
        ```bash
        $ java -Dwebdriver.chrome.driver=chromedriver -jar selenium-server-standalone.jar
        ```
        
    3. Run test application's webserver on `localhost:8080`:
    
        ```bash
        $ (cd tests/Application && bin/console server:run localhost:8080 -d public -e test)
        ```
    
    4. Run Behat:
    
        ```bash
        $ vendor/bin/behat --tags="@javascript"
        ```

### Opening Sylius with your plugin

After installation and with docker containers running, go to http://0.0.0.0:9000/
